@@ -5,7 +5,7 @@ package VMware::vCloudDirector2::Link;
 use strict;
 use warnings;
 
-our $VERSION = '0.101'; # VERSION
+our $VERSION = '0.102'; # VERSION
 our $AUTHORITY = 'cpan:NIGELM'; # AUTHORITY
 
 use Moose;
@@ -42,7 +42,7 @@ around BUILDARGS => sub {
         $params->{href} = $hash->{href} if ( exists( $hash->{href} ) and defined( $hash->{href} ) );
         $params->{rel}  = $hash->{rel}  if ( exists( $hash->{rel} )  and defined( $hash->{rel} ) );
         $params->{name} = $hash->{name} if ( exists( $hash->{name} ) and defined( $hash->{name} ) );
-        if ( exists( $hash->{type} ) ) {
+        if ( exists( $hash->{type} ) and defined( $hash->{type} ) ) {
             my $type = $hash->{type};
             $params->{mime_type} = $type;
             if ( $type =~ m!^application/vnd\..*\.(\w+)\+(json|xml)$! ) {
@@ -87,7 +87,7 @@ VMware::vCloudDirector2::Link - Link within the vCloud
 
 =head1 VERSION
 
-version 0.101
+version 0.102
 
 =head3 DELETE
 
